/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.except.*;

public class ConferenceCustomBlocks implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.ConferenceCustomBlocks";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private CommunityContext comm;        // the community we're in
  private ConferenceContext conf;       // the conference being diddled with
  private String top_custom;            // the top custom block
  private String bottom_custom;         // the bottom custom block
  private String locator = null;        // locator string

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public ConferenceCustomBlocks(CommunityContext comm, ConferenceContext conf) throws DataException
  {
    this.comm = comm;
    this.conf = conf;
    this.top_custom = conf.getCustomBlock(ConferenceContext.CUST_BLOCK_TOP);
    this.bottom_custom = conf.getCustomBlock(ConferenceContext.CUST_BLOCK_BOTTOM);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static ConferenceCustomBlocks retrieve(ServletRequest request)
  {
    return (ConferenceCustomBlocks)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "Customize Conference: " + conf.getName();

  } // end getPageTitle

  public String getPageQID()
  {
    return null;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "conf_custom.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public final int getCommunityID()
  {
    return comm.getCommunityID();

  } // end getCommunityID

  public final int getConferenceID()
  {
    return conf.getConfID();

  } // end getConferenceID

  public final String getConferenceName()
  {
    return conf.getName();

  } // end getConferenceName

  public final String getLocator()
  {
    if (locator==null)
      locator = "sig=" + comm.getCommunityID() + "&conf=" + conf.getConfID();
    return locator;

  } // end getLocator

  public final String getTopCustomBlock()
  {
    return (top_custom==null) ? "" : StringUtil.encodeHTML(top_custom);

  } // end getTopCustomBlock

  public final String getBottomCustomBlock()
  {
    return (bottom_custom==null) ? "" : StringUtil.encodeHTML(bottom_custom);

  } // end getBottomCustomBlock

} // end class ConferenceCustomBlocks
